import random
import string

class UUIDGenerator:

	def __init__(self, dtype='str-major', seed=None):
		self.dtype = dtype
		if seed is not None:
			self.seed = seed
		else:
			self.seed = random.randint(1, 200)
	def generate(self):
		if self.dtype == 'int-major':
			self.result = []
			length = 22
			data = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0', '&', '-', '%', '#', '@']
			self.result = ''.join(random.choice(data) for i in range(length))

		elif self.dtype == 'str-major':
			length = 22
			letters = string.ascii_lowercase + string.ascii_uppercase + '-%$#@!&^*(){}[]><?/|'
			self.result = ''.join(random.choice(letters) for i in range(length))
		
		else:
			self.result = 'Unknown UUID data-type mentioned'

		return self.result


from setuptools import setup, find_packages
from os import path

__version__ = '1.2'

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='placeholderfile',
    version=__version__,
    description='Generates placeholderfile name',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/theroyakash/placeholderfile',
    download_url='https://github.com/theroyakash/placeholderfile/tarball/main',
    license='Apache License',
    packages=find_packages(),
    include_package_data=True,
    author='theroyakash',
    author_email='royakashappleid@icloud.com'
)


import random
import string

def generateName(suffix = None, prefix = None, seed=None):
	length = 10
	if seed is not None:
		random.seed = seed

	letters = string.ascii_lowercase
	filename = ''.join(random.choice(letters) for i in range(length))
	
	if suffix is None and prefix is None:
		return filename
	elif suffix is not None and prefix is None:
		return filename + suffix
	elif suffix is None and prefix is not None:
		return prefix + filename
	else:
		return prefix + filename + suffix